            <div class="user-dashboard">
                <div class="container">
                <div class="col-xl-12 col-lg-12">
                    <div class="row">
                        <div class="col-6"> 
                            <h3>District Names</h3>
                         </div>
                         <div class="col-6" style="text-align: right;"> 
                            <button class="btn-save" onclick="addform()">New</button>
                         </div>
                        </div>                                                 
                        </div>
                   <div class="row">
                <div class="col-xl-12 col-lg-12">
                    <div class="transactions-table table">
                        <div class="table">
                            <table id="listTable" class="table" style="width:100%">
                                <thead>
                                    <tr>
                                        <th style="width:150px">Code</th>
                                        <th>District Name</th>
                                        <th>State Name</th>
                                        <th>Country Name</th>
                                        <th style="width:50px">Status</th>
                                        <th style="width:100px"></th>
                                    </tr>
                                </thead>                                     
                                <tbody id="tbl_content"> <tr>
                                    <td colspan='6'>
                                            <?php echo loadingText("Loading District Names");?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
      </div>
</div>

<div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">New District Name</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                 <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
                <div class="row">
                     <span id="ErrCommon"></span>
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                        <span id="ErrCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Country Name</label><span style='color:red'>*</span>
                          <select class="form-select form-select-sm" name="CountryNameID" id="CountryNameID" onchange="clearInput('CountryNameID');listStateNames('frm_create','StateNameID','0')">
                            <option value="0">Select Country Name</option>                            
                         </select>
                        <span id="ErrCountryNameID" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">State Name</label><span style='color:red'>*</span>
                            <select class="form-select form-select-sm" name="StateNameID" id="StateNameID" onchange="clearInput('StateNameID');">
                            <option value="0">Select State Name</option>
                         </select>
                        <span id="ErrStateNameID" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">District Name</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="DistrictName" name="DistrictName" placeholder="District Name" value="" onchange="clearInput('DistrictName')">
                        <span id="ErrDistrictName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('Remarks')">
                        <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
                </form>
            </div>                                           
            <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="add()"class="btn-save">Save</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
                                                                                                            
<div class="modal fade" id="confirmationtoedit" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Edit District Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                 <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
                 <input type="hidden" name="ID" id="editID">
                <div class="row">
                     <span id="ErreditCommon"></span>
                    <div class="col-6">
                        <label class="form-label">Code</label>
                        <input class="form-control form-control-sm" type="text" readonly="readonly" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="clearInput('editCode')">
                        <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Country Name</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="CountryNameID" id="editCountryNameID" onchange="clearInput('editCountryNameID');;listStateNames('frm_edit','editStateNameID','0')">
                            <option value="0">Select Country Name</option>
                         </select>
                        <span id="ErreditCountryNameID" class="error_msg" style="color: red;"></span>
                    </div>
                     <div class="col-12">
                        <label class="form-label">State Name</label><span style='color:red'>*</span>
                         <select class="form-select form-select-sm" name="StateNameID" id="editStateNameID" onchange="clearInput('editStateNameID')">
                            <option>Select State Name</option>
                         </select>
                        <span id="ErreditStateNameID" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">District Name</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="editDistrictName" name="DistrictName" placeholder="District Name" value="" onkeypress="clearInput('editDistrictName')">
                        <span id="ErreditDistrictName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-sm-6">
                        <label class="form-label">Status</label>
                        <select name="Status" id="editStatus" class="form-select form-select-sm">
                            <option value="1">Active</option>
                            <option value="0">Deactive</option>
                        </select>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('editRemarks')">
                        <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="edit()" class="btn-save">Update</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoview" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">View District Name</h5>
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Code</div>
                         <div id="viewCode"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Country Name</div>
                         <div id="viewCountryNameID"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">State Name</div>
                         <div id="viewStateNameID"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">District Name</div>
                         <div id="viewDistrictName"></div>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Remarks</div>
                         <div id="viewRemarks"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Status</div>
                         <div id="viewStatus"></div>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Created On</div>
                         <div id="viewCreatedOn"></div>
                    </div>
                </div>
            </div>
            <div class="modal-footer"> 
                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-body" style="text-align: center;">
                <div id="sucess">
                    <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                </div>
                <h3 class="title">Success.</h3>  
                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
            </div>
        </div>
    </div>
</div>
     
<script>

function list() {
      $('#Success').modal("hide");
    $.post(URL+ "webservice.php?action=l&method=mcdnl","",function(data){
      var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "";
            i=0;
            $.each(obj.data, function (index, data) {
                html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
                            + '<td>' + data.Code + '</td>'
                            + '<td>' + data.DistrictName     + '</td>' 
                            + '<td>' + data.StateName + '</td>' 
                            + '<td>' + data.CountryName + '</td>' 
                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
                             + '<td style="text-align:right">' 
                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
                               + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'mcdnl\',\''+data.DistrictName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
                               + '</td>'
                             + '</tr>' 
                      + '</tr>';
                      i++;
            });
            if(obj.data.length==0){
            html += '<tr>'
                + '<td colspan="6" style="text-align: center;background:#fff !important">No data found</td>'
                + '</tr>'
            }   
            $('#tbl_content').html(html);
        } else {
             $('#popupcontent').html( error(obj.message));
        }  
    });
}

setTimeout("list()",2000);

function addform(){
listCountryNames("frm_create","CountryNameID","0");

     
    $('#confirmationtoadd').modal("show"); 
    $('#Code').val(""); 
    $('#StateNameID').val("0"); 
    $('#CountryNameID').val("0"); 
    $('#DistrictName').val(""); 
    $('#Remarks').val(""); 
    
    $('#ErrCode').html(""); 
    $('#ErrStateNameID').html(""); 
    $('#ErrCountryNameID').html(""); 
    $('#ErrDistrictName').html(""); 
    $('#ErrRemarks').html("");
    $('#ErrCommon').html("");
    
    $("#Code").removeClass("highlight_error"); 
    $("#StateNameID").removeClass("highlight_error"); 
    $("#CountryNameID").removeClass("highlight_error"); 
    $("#DistrictName").removeClass("highlight_error"); 
    $("#Remarks").removeClass("highlight_error");
}

function add(){                                           
     var error = 0;
       if ($('#Code').val()==""){
            $('#ErrCode').html("Please enter Code");
         $("#Code").addClass("highlight_error"); 
            error++;                                                                         
    }  else {
        $("#Code").removeClass("highlight_error"); 
            $('#ErrCode').html(""); 
    }
    if ($('#StateName').val()=="0"){
            $('#ErrStateName').html("Please Select State Name");
          $("#StateName").addClass("highlight_error"); 
            error++;
    }  else {
            $("#StateName").removeClass("highlight_error"); 
            $('#ErrStateName').html(""); 
    } 
     if ($('#CountryNameID').val()=="0"){
            $('#ErrCountryNameID').html("Please Select Country Name");
          $("#CountryNameID").addClass("highlight_error"); 
          error++;
    }  else {
         $("#CountryNameID").removeClass("highlight_error"); 
            $('#ErrCountryNameID').html(""); 
    } 
    if ($('#DistrictName').val()==""){
            $('#ErrDistrictName').html("Please enter District Name");
             $("#DistrictName").addClass("highlight_error"); 
            error++;
    }  else {
          $("#DistrictName").removeClass("highlight_error"); 
            $('#ErrDistrictName').html(""); 
    } 
     if(error==0){
        var param = $('#frm_create').serialize();
        $.post(URL+"webservice.php?action=a&method=mcdnl",param,function(data){
        var obj = JSON.parse(data); 
        if (obj.status=="success") {
             $('#confirmationtoadd').modal("hide"); 
             $('#Success').modal("show");    
        }   else {
            $('#ErrCommon').html(print_inlineError(obj.message));
        }
    });
   } 
}

function editform(ID) {
   
     $('#confirmationtoedit').modal("show"); 
     $('#ErreditCode').html(""); 
     $('#ErreditStateName').html(""); 
     $('#ErreditCountryName').html(""); 
     $('#ErreditDistrictName').html(""); 
     $('#ErreditRemarks').html("");
     $("#editCode").removeClass("highlight_error"); 
     $("#editStateName").removeClass("highlight_error"); 
     $("#editCountryName").removeClass("highlight_error"); 
     $("#editDistrictName").removeClass("highlight_error"); 
     $("#editRemarks").removeClass("highlight_error");
     $('#ErreditCommon').html("");
     $.post(URL+ "webservice.php?action=g&method=mcdnl&ID="+ID,"",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "";
             _CountryNameID="";
             _StateNameID="";
            $.each(obj.data, function (index, data) {
                $('#editCode').val(data.Code);
                $('#editID').val(data.ID);
                $('#editDistrictName').val(data.DistrictName);
                $('#editStatus').val(data.Status);
                $('#editRemarks').val(data.Remarks);
                _CountryNameID=data.CountryNameID;
                _StateNameID=data.StateNameID;
            }); 
             if (obj.data.length>0)    {
                 listCountryNames("frm_edit","editCountryNameID",_CountryNameID);
                 setTimeout(function(){
                 listStateNames("frm_edit","editStateNameID",_StateNameID);    
                 },2000);
                 
            }  
}  
        else {
            $('#ErreditCommon').html(print_inlineError(obj.message));
        }
  });  
}

function edit(ID){
      var error = 0;
    if ($('#editCode').val()==""){
            $('#ErreditCode').html("Please enter Code");
           $("#editCode").addClass("highlight_error"); 
            error++;
    }  else {
         $("#editCode").removeClass("highlight_error"); 
            $('#ErreditCode').html(""); 
    }
     if ($('#editStateName').val()=="0"){
            $('#ErreditStateName').html("Please Select State Name");
         $("#editStateName").addClass("highlight_error"); 
          error++;
    }  else {
         $("#editStateName").removeClass("highlight_error"); 
            $('#ErreditStateName').html(""); 
    } 
      if ($('#editCountryName').val()=="0"){
            $('#ErreditCountryName').html("Please Select Country Name");
             $("#editCountryName").addClass("highlight_error"); 
           error++;
    }  else {
         $("#editCountryName").removeClass("highlight_error"); 
            $('#ErreditCountryName').html(""); 
    } 
    if ($('#editDistrictName').val()==""){
            $('#ErreditDistrictName').html("Please enter District Name");
          $("#editDistrictName").addClass("highlight_error"); 
           error++;
    }  else {
          $("#editDistrictName").removeClass("highlight_error"); 
            $('#ErreditDistrictName').html(""); 
    }  
    if(error==0){
            var param = $('#frm_edit').serialize();
            $.post(URL+"webservice.php?action=u&method=mcdnl",param,function(data){
            var obj = JSON.parse(data); 
            if (obj.status=="success") {
                 $('#confirmationtoedit').modal("hide");
                 $('#Success').modal("show");  
            }   else {
                $('#ErreditCommon').html(print_inlineError(obj.message));
            }
        });
       } 
  
}

function viewform(ID){
     $('#confirmationtoview').modal("show");
      $.post(URL+ "webservice.php?action=g&method=mcdnl&ID="+ID,"",function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            $.each(obj.data, function (index, data) {
                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
                $('#viewCountryNameID').html(data.CountryName=="" ? "&nbsp" : data.CountryName);
                $('#viewStateNameID').html(data.StateName=="" ? "&nbsp" : data.StateName);
                $('#viewDistrictName').html(data.DistrictName=="" ? "&nbsp" : data.DistrictName);
                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
               if(data.Status=="1"){
                $('#viewStatus').html("Active");    
               }
               if(data.Status=="0"){
                $('#viewStatus').html("Deactive");    
               }
            });   
}  
  }) 
}

function listCountryNames(formID,selectboxID,selected) {
    var param = $('#'+formID).serialize();
    $.post(URL+ "webservice.php?action=lac&method=mccol",param,function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            var html = "<option value='0'>Select Country Name</option>";
            $.each(obj.data, function (index, data) {
                html += '<option value="'+data.ID+'" '+((data.ID==selected) ? ' selected="selected" ' : '')+'>'+data.CountryName+'</option>';
            });   
                $('#'+selectboxID).html(html);
        } else {
             var html = "<option value='0'>Select Country Name</option>";
              $('#'+selectboxID).html(html);
           // $('#ErrCommon').html( errorcontent(obj.message));
        }
    })
}



function listStateNames(formID,selectboxID,selected) {
    
    var html = "<option value='0'>Select State Name</option>";
             $('#'+selectboxID).html(html);
    if (formID=="frm_create") {
          if ($('#CountryNameID').val()=="0") {
              var html = "<option value='0'>Select State Name</option>";
             $('#'+selectboxID).html(html);
          }
    }
    if (formID=="frm_edit") {
         if ($('#editCountryNameID').val()=="0") {
              var html = "<option value='0'>Select State Name</option>";
             $('#'+selectboxID).html(html);
          }
        
    }
      var param = $('#'+formID).serialize();
    $.post(URL+ "webservice.php?action=labc&method=mcsnl",param,function(data){
        var obj = JSON.parse(data);
        if (obj.status=="success") {
            if (obj.data.length>0) {
            var html = "<option value='0'>Select State Name</option>";
            $.each(obj.data, function (index, data) {
                html += '<option value="'+ data.ID +'" '+((data.ID==selected) ? ' selected="selected" ' : '')+' ">'+data.StateName+'</option>';
            });
            $('#'+selectboxID).html(html);
            }
        } else {
             var html = "<option value='0'>Select State Name</option>";
             $('#'+selectboxID).html(html);
           // $('#ErrCommon').html( errorcontent(obj.message));
        }
    })
}

   
//Character Limitations
 

/*Alphanumeric without space*/
var arr = ["Code","editCode"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}


/* Alphabets Space Dot only correct */ 
var arr = ["DistrictName","editDistrictName"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,186,187,189,173,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46,103,104,105,100,101,102,97,98,99,96,110,190]
                var allowedkeys  = [9,8,32,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,110]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}



/* Alphnumeric and special characters, not allow !\$"'~  */
var arr = ["Remarks","editRemarks"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [220,222,49,52,192]
               var allowedkeys  = [9,8,46,32,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,103,104,105,100,101,102,97,98,99,96,48,49,50,51,52,53,54,55,56,57,173,61,110,190,191,221,219,111,106,109,107,59,188]
               if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
} 
 
  
</script>
    